@@ -106,7 +106,7 @@ DcmElement* DICOMImg2DCM::CrearElementoConValor(const char* s)
                 DcmTagKey key(0xffff, 0xffff);
                 const DcmDataDictionary& globalDataDict = dcmDataDict.rdlock();
                 const DcmDictEntry *dicent = globalDataDict.findEntry(dicName.c_str());
-                dcmDataDict.unlock();
+                dcmDataDict.rdunlock();
                 if (dicent != NULL) {
                         // found dictionary name, copy group and element number
                         key = dicent->getKey();
@@ -403,7 +403,7 @@ void DICOMImg2DCM::Inicializar(D2DSource* plugEntrada, IInspectCallBack* pICallb
                                 }
                         }
                 }
-                dcmDataDict.unlock();
+                dcmDataDict.wrunlock();
         }
 
 
